#!/bin/bash

srcdir=$(pwd)
prefix=/usr
bindir=${prefix}/bin
datadir=${prefix}/share
mandir=${datadir}/man
infodir=${datadir}/info

buildroot=/tmp/tetex
texmf=${datadir}/texmf
build_texmf=${buildroot}${texmf}

version=2.0.2
ptex_src_ver=3.1.3

( cd tetex-src-${version}
  rm -fr ${buildroot}
  unset TEXINPUTS

  mkdir -p ${build_texmf}
  tar cf - texmf | tar xf - -C ${build_texmf}/../
  LD_LIBRARY_PATH=${buildroot}${prefix}/lib make \
    prefix=${buildroot}${prefix} texmf=${build_texmf} \
    mandir=${buildroot}${mandir} bindir=${buildroot}${bindir} \
    infodir=${buildroot}${infodir} install

  ## for ptex
  # enable 'make formats'
  TEXMFMAIN=${build_texmf} PATH=${buildroot}${bindir}:$PATH texhash 
  ( cd texk/web2c/ptex-src-${ptex_src_ver}
    make prefix=${buildroot}${prefix} texmf=${build_texmf} \
      mandir=${buildroot}${mandir} bindir=${buildroot}${bindir} \
      infodir=${buildroot}${infodir} install
  )
  cat <<EOF >> ${build_texmf}/web2c/fmtutil.cnf

# Japanese pTeX:
ptex            ptex            -               ptex.ini
platex          ptex            language.dat    platex.ini
platex209       ptex            language.dat    plplain.ini
EOF

  echo "\input plplain.tex \dump" > ${build_texmf}/ptex/platex209/plplain.ini
  install ${srcdir}/jtygm.sty ${build_texmf}/ptex/platex/base/

  ( export TEXMFMAIN=${build_texmf} PATH=${buildroot}${bindir}:$PATH LD_LIBRARY_PATH=${buildroot}${prefix}/lib
    texhash && texconfig init && texlinks
  )

  ## for dvipdfmx
  rm ${buildroot}${bindir}/dvipdfm
  ln -s ${bindir}/dvipdfmx ${buildroot}${bindir}/dvipdfm

  ## delete useless files (conflict with jvf package)
  rm -rf ${build_texmf}/fonts/vf/ptex
  rm -rf ${build_texmf}/fonts/tfm/ptex/{gbm,gbmv,rml,rmlv}.tfm

  rm -f ${buildroot}${infodir}/dir
  ( export TEXMFMAIN=${build_texmf} PATH=${buildroot}${bindir}:$PATH texhash )

  # for created fonts
  mkdir -p ${buildroot}/var/lib/texmf
  #mkdir -p ${buildroot}/etc/cron.daily
  #install -m755 ${srcdir}/tetex.cron ${buildroot}/etc/cron.daily

  # add suffix
  ( cd ${buildroot}${bindir}
    for file in *; do
      echo $file | egrep '(\.dll|\.exe)' > /dev/null && continue
      if [ ! -L $file ]; then
        res=`file $file | grep PE`
        if [ "x$res" != "x" ]; then mv $file $file.exe; fi
      fi
    done
  )
  # Strip binaries
  strip ${buildroot}${bindir}/*.exe || :
  strip ${buildroot}${bindir}/*.dll || :

  # create some useful link.
  ln -s kpsetool ${buildroot}${bindir}/kpsexpand
  ln -s platex   ${buildroot}${bindir}/latex
)

